This enables flashing the Dell S1850 under Linux. 
This code has been tested. 
Signed-off-by: Carl-Daniel Hailfinger <c-d.hailfinger.devel.2006@gmx.net>
Acked-by: Ronald G. Minnich <rminnich@gmail.com>

Index: flashrom/board_enable.c
===================================================================
--- flashrom/board_enable.c	(revision 615)
+++ flashrom/board_enable.c	(working copy)
@@ -591,6 +591,18 @@
 }
 
 /**
+ * Suited for the Dell S1850. All parameters except the last one are documented
+ * in the public Intel 82801EB ICH5 / 82801ER ICH5R Datasheet. The last
+ * parameter (GPIO number) has to be in the range [16,31] according to said
+ * Intel Datasheet and can be found by exhaustive search.
+ */
+static int ich5_gpio23_raise(const char *name)
+{
+       return ich_gpio_raise(name, 0x8086, 0x24d0, 0x58, 0x0c, 0xffc0, 0x800000);
+}
+
+
+/**
  * Suited for MSI MS-7046.
  */
 static int ich6_gpio19_raise(const char *name)
@@ -818,6 +830,7 @@
 	{0x8086, 0x1a30, 0x1043, 0x8070,  0x8086, 0x244b, 0x1043, 0x8028, NULL,         NULL,          "ASUS",        "P4B266",             ich2_gpio22_raise},
 	{0x10B9, 0x1541,      0,      0,  0x10B9, 0x1533,      0,      0, "asus",       "p5a",         "ASUS",        "P5A",                board_asus_p5a},
 	{0x1106, 0x3149, 0x1565, 0x3206,  0x1106, 0x3344, 0x1565, 0x1202, NULL,         NULL,          "BioStar",     "P4M80-M4",           board_biostar_p4m80_m4},
+	{0x8086, 0x3590, 0x1028, 0x016c,  0x1000, 0x0030, 0x1028, 0x016c, NULL,NULL,         "Dell",     "S1850",           ich5_gpio23_raise},
 	{0x1106, 0x3177, 0x1106, 0x3177,  0x1106, 0x3059, 0x1695, 0x3005, NULL,         NULL,          "EPoX",        "EP-8K5A2",           board_epox_ep_8k5a2},
 	{0x8086, 0x7110,      0,      0,  0x8086, 0x7190,      0,      0, "epox",       "ep-bx3",      "EPoX",        "EP-BX3",             board_epox_ep_bx3},
 	{0x1039, 0x0761,      0,      0,       0,      0,      0,      0, "gigabyte",   "2761gxdk",    "GIGABYTE",    "GA-2761GXDK",        it87xx_probe_spi_flash},
